This function is a wrapper function of the WWARN PCE method to calculate the parasite clearance rates of a given data set of patient profiles. The function returns the output data frame and it also saves more comprehensive outputs under a folder named "PceEstimates" under the current working directory.
calculatePCE(data, detect.limit = 15, outlier.detect = TRUE, ...)a data frame containing the profiles of patients.
This data frame must contain id, time, and count columns,
in that order. The first column represents the IDs of patients.
The second and third columns contain parasite measurements (per microliter) in different times.
detection limit of the parasite density in blood
indicator of whether or not to use Flegg's outlier detection method
additional parameters.
All results are saved under a folder named "PceEstimates" under the current working directory.
Output data frame. If outlier.detect = TRUE, the cleaned data frame will be returned.
This function gives users a way to calculate the parasite clearance rates by using the method in Flegg et al. (2011).
Users can compare the results with that given by our method of Bayesian heierarchical model. The output is saved under
a folder named "PceEstimates" under the current working directory. data should be a data frame in the form of the example data
pursat provided in this package. detect.limit is the detection limit of the parasite density in blood. The default
value is set to be 15. outlier.detect is an indicator users can turn off if the dataset has already been cleaned. Otherwise,
it is always recommended to set outlier.detect = TRUE to let the program automatically detect outliers in the dataset.
Flegg, J. A., Guerin, P. J., White, N. J., & Stepniewska, K. (2011). Standardizing the measurement of parasite clearance in falciparum malaria: the parasite clearance estimator. Malaria journal, 10(1), 339.
# NOT RUN {
data("pursat")
output <- calculatePCE(data = pursat, detect.limit = 15, outlier.detect = TRUE)
# }
Run the code above in your browser using DataLab