Learn R Programming

bhrcr (version 1.0.3)

posterior: Description of the Dataset posterior.rda

Description

The output given by clearanceEstimatorBayes in the slow demo example, which is calculated and saved ahead of time to save users' time.

Usage

data("posterior")

Arguments

Format

A data frame of class "bhrcr".