Learn R Programming

bhrcr (version 1.0.3)

print.bhrcr: Print Function for the Bayesian Clearance Estimator

Description

print.bhrcr prints the estimated effect of covariates on both log clearance rates and log half-lives.

Usage

# S3 method for bhrcr
print(x, ...)

Arguments

x

an object of class bhrcr, given by clearanceEstimatorBayes.

...

additional parameters.

Value

the input object is returned silently.

Details

This function prints the posterior mean value of gamma, which represents the effect of covariates on log clearance rates. It also prints the estimated impact of covariates on log half-lives.

Examples

Run this code
# NOT RUN {
data("posterior")
print(posterior)
# }
# NOT RUN {
data("pursat")
data("pursat_covariates")
out <- clearanceEstimatorBayes(data = pursat, covariates = pursat_covariates, 
                               niteration = 200, burnin = 50, thin = 10)
print(out)
# }

Run the code above in your browser using DataLab