Learn R Programming

bhrcr (version 1.0.3)

summary.bhrcr: Summary Statistics for the Bayesian Clearance Estimator

Description

summary.bhrcr provides summary statistics for the effect of covariates on both log clearance rates and log half-lives.

Usage

# S3 method for bhrcr
summary(object, ...)

Arguments

object

an object of class bhrcr, given by clearanceEstimatorBayes.

...

additional parameters.

Value

the input object is returned silently.

Details

This function provides mean, median, and credible intervals for gamma, which represents the effect of covariates on log clearance rates. It also provides those statistics for the effect of covariates on log half-lives.

Examples

Run this code
# NOT RUN {
data("posterior")
summary(posterior)
# }
# NOT RUN {
data("pursat")
data("pursat_covariates")
out <- clearanceEstimatorBayes(data = pursat, covariates = pursat_covariates, 
                               niteration = 200, burnin = 50, thin = 10)
summary(out)
# }

Run the code above in your browser using DataLab