powered by
posterior.rda
The output given by clearanceEstimatorBayes in the slow demo example, which is calculated and saved ahead of time to save users' time.
clearanceEstimatorBayes
data("posterior")
A data frame of class "bhrcr".